Struct ar::Entry
[−]
[src]
pub struct Entry<'a, R: 'a + Read> { /* fields omitted */ }Representation of an archive entry.
Entry objects implement the Read trait, and can be used to extract the
data from this archive entry. If the underlying reader supports the Seek
trait, then the Entry object supports Seek as well.
Methods
impl<'a, R: 'a + Read> Entry<'a, R>[src]